import time
import threading
import traceback

from libraries.exceptions.auraexceptions import LQConnectionError


class LiquidSoapInitThread(threading.Thread):
    socket = None
    liquidsoapcommunicator = None

    def __init__(self, liquidsoapcommunicator):
        threading.Thread.__init__(self)

        self.liquidsoapcommunicator = liquidsoapcommunicator

    def run(self):
        try:
            # sleep needed, because the socket is created to slow by liquidsoap
            time.sleep(5)

            # enable lqs transaction
            self.liquidsoapcommunicator.enable_transaction(True)

            # reset channels and reload them
            self.liquidsoapcommunicator.channels = None
            channels = self.liquidsoapcommunicator.get_all_channels()

            # set every volume to 0
            for c in channels:
                self.liquidsoapcommunicator.channel_volume(c, "0")

            self.liquidsoapcommunicator.playlist_push(self.liquidsoapcommunicator.config.get("install_dir")+"/configuration/blank.flac")
            self.liquidsoapcommunicator.set_http_url("http://stream.fro.at/fro-128.ogg")

            # select all channels
            for c in channels:
                self.liquidsoapcommunicator.channel_activate(c, True)

            time.sleep(3)
            activechannel = self.liquidsoapcommunicator.get_active_channel()

            if self.liquidsoapcommunicator.debug > 2:
                print("LiquidSoapInitThread sets activechannel: "+str(activechannel))

            if activechannel != "" and activechannel is not None:
                self.liquidsoapcommunicator.channel_volume(activechannel.value, 100)
                #self.liquidsoapcommunicator.__send_lqc_command__(self.socket, "mixer", "volume", activechannel, 100)

            self.liquidsoapcommunicator.disable_transaction(True)
        except LQConnectionError as e:
            print("Liquidsoap connection ERROR! Restart LQ Server!")
            print(e.message)
            print(e)
        except Exception as e:
            traceback.print_exc()
            print(e)


